/*
    example2b.c: Read application data written to SmartDongle in example2a.c

    MicroWorks, Inc.
    2808 North Cole Road
    Boise, ID 83704

    www.smartdongle.com


    ***** BEGIN LICENSE BLOCK *****

    Version: MPL 1.1/GPL 2.0/LGPL 2.1

    The contents of this file are subject to the Mozilla Public License
    Version 1.1 (the "License"); you may not use this file except in
    compliance with the License. You may obtain a copy of the License at
    http://www.mozilla.org/MPL/

    Software distributed under the License is distributed on an "AS IS" basis,
    WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
    for the specific language governing rights and limitations under the
    License.

    The Original Code is MicroWorks, Inc. code.

    The Initial Developer of the Original Code is MicroWorks, Inc. Portions
    created by MicroWorks, Inc. are Copyright (C) 2008
    MicroWorks, Inc. All Rights Reserved.

    Contributor(s):

    Alternatively, the contents of this file may be used under the terms of
    either the GNU General Public License Version 2 or later (the "GPL"), or
    the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
    in which case the provisions of the GPL or the LGPL are applicable instead
    of those above. If you wish to allow use of your version of this file only
    under the terms of either the GPL or the LGPL, and not to allow others to
    use your version of this file under the terms of the MPL, indicate your
    decision by deleting the provisions above and replace them with the notice
    and other provisions required by the GPL or the LGPL. If you do not delete
    the provisions above, a recipient may use your version of this file under
    the terms of any one of the MPL, the GPL or the LGPL.

    ***** END LICENSE BLOCK *****
*/
#include <stdio.h>
#include <string.h>
#include "smartdongle.h"

/*
    Your application data here.
*/
#define YOUR_DATA "This is data written to the SmartDongle, it can be serial numbers, program parameters, etc.  Note that this data can be read by observing activity on the USB bus. Refer to example3a.c and example3b.c for example of encrypting your application data."

int main ( int argc, char **argv) {

    /* SmartDongle demo keys. */
    unsigned long long P1 = 0xec6cc589aefd1e75ULL;
    unsigned long long P2 = 0xfcec0a6a82747b3fULL;

    unsigned char data[] = YOUR_DATA;
    unsigned char *in;
    unsigned short address;
    int length;
    char errorString[SMARTDNGL_ERROR_STRING_LENGTH_MAX];
    int error = SMARTDNGL_ERR_OK;


    /*
        Allocate input buffer for expected application data size
        plus one for C string null terminator.
    */
    length = strlen((char *)data) + 1;
    in = (unsigned char *)malloc(length);
    if (in == NULL) {
        error = SMARTDNGL_ERR_MEM;
        SmartDongleGetErrorString(errorString, error);
        printf("%s\n", errorString);
        return 1;
    }

    /*
        Read the application data written in example2a.c
    */
    address = 0;
    error = SmartDongleRead(&P1, &P2, address, in, length);
    if (error) {
        SmartDongleGetErrorString(errorString, error);
        printf("SmartDongle Read Failed %d, %s\n", error, errorString);
        return 1;
    }

    /*
       This exercise simply compares the data read from the SmartDongle with
       the expected application data.  A developer could do any number of
       things with the data.
    */
    if (memcmp(in, data, length) == 0) {
        printf("Success: SmartDongle has the expected application data\n");
    } else {
        printf("SmartDongle does not have the expected application data\n");
        return 1;
    }

    return 0;
}
