/*
   example4.c: Read SmartDongle serial number and memory size

   MicroWorks, Inc.
   2808 North Cole Road
   Boise, ID 83704

   www.smartdongle.com


   ***** BEGIN LICENSE BLOCK *****

   Version: MPL 1.1/GPL 2.0/LGPL 2.1

   The contents of this file are subject to the Mozilla Public License
   Version 1.1 (the "License"); you may not use this file except in
   compliance with the License. You may obtain a copy of the License at
   http://www.mozilla.org/MPL/

   Software distributed under the License is distributed on an "AS IS" basis,
   WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
   for the specific language governing rights and limitations under the
   License.

   The Original Code is MicroWorks, Inc. code.

   The Initial Developer of the Original Code is MicroWorks, Inc. Portions
   created by MicroWorks, Inc. are Copyright (C) 2008
   MicroWorks, Inc. All Rights Reserved.

   Contributor(s):

   Alternatively, the contents of this file may be used under the terms of
   either the GNU General Public License Version 2 or later (the "GPL"), or
   the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
   in which case the provisions of the GPL or the LGPL are applicable instead
   of those above. If you wish to allow use of your version of this file only
   under the terms of either the GPL or the LGPL, and not to allow others to
   use your version of this file under the terms of the MPL, indicate your
   decision by deleting the provisions above and replace them with the notice
   and other provisions required by the GPL or the LGPL. If you do not delete
   the provisions above, a recipient may use your version of this file under
   the terms of any one of the MPL, the GPL or the LGPL.

   ***** END LICENSE BLOCK *****
*/
#include <stdio.h>
#include <string.h>
#include "smartdongle.h"

int main ( int argc, char **argv) {

    int error;
    int userMemorySize;
    char sn[SMARTDNGL_SN_LENGTH * 10 + 1];
    char errorString[SMARTDNGL_ERROR_STRING_LENGTH_MAX];

    /* SmartDongle demo keys. */
    unsigned long long P1 = 0xec6cc589aefd1e75ULL;
    unsigned long long P2 = 0xfcec0a6a82747b3fULL;


    /*
        Note:

        If error code 41 or 42 is returned from functions below, the problem
        may be that the mode of the dynamic SmartDongle device files in
        /proc/bus/usb/ and /dev/bus/usb/ do not allow user access.

        As of linux kernel version 2.6.x, permissions can be set with hal
        facilities.  Refer to HAL/README.txt
    */


    /*
        Retrieve SmartDongle serial number
    */
    error = SmartDongleGetSerialNumber(sn);
    if (error) {

        SmartDongleGetErrorString(errorString, error);
        printf("FAIL: error %d, %s\n", error, errorString);
    } else {

        printf("Serial Number: %s\n", sn);
    }

    /*
        Retrieve SmartDongle memory size that is available to user
    */
    userMemorySize = SmartDongleGetEepromSize(&P1, &P2);
    if (userMemorySize < 0) {

        SmartDongleGetErrorString(errorString, -userMemorySize);
        printf("FAIL: error %d, %s\n", -userMemorySize, errorString);
    } else {

        printf("User memory size: %d\n", userMemorySize);
    }

   return 0;
}
